@@ -121,7 +121,9 @@ def read_pkg_file(self, file):
 def single_line(val):
     # quick and dirty validation for description pypa/setuptools#1390
     if '\n' in val:
-        raise ValueError("newlines not allowed")
+        # TODO after 2021-07-31: Replace with `raise ValueError("newlines not allowed")`
+        warnings.UserWarning("newlines not allowed and will break in the future")
+        val = val.replace('\n', ' ')
     return val
 
 
